@@ -1,6 +1,6 @@
 import logging
 from statina.adapter import StatinaAdapter
-from statina.models.database import DataBaseSample, User
+from statina.models.database import DataBaseSample, User, Batch
 
 LOG = logging.getLogger(__name__)
 
@@ -14,6 +14,14 @@ def sample(adapter: StatinaAdapter, sample: DataBaseSample) -> None:
     adapter.sample_collection.update_one({"sample_id": sample_id}, {"$set": sample_dict})
 
 
+def update_batch(adapter: StatinaAdapter, batch: Batch) -> None:
+    """Update a batch object in the database"""
+    batch_dict: dict = batch.dict(exclude_none=True)
+    batch_id = batch.batch_id
+    LOG.info("Updating batch %s", batch_id)
+    adapter.batch_collection.update_one({"batch_id": batch_id}, {"$set": batch_dict})
+
+
 def update_user(adapter: StatinaAdapter, user: User) -> None:
     """Update a user object in the database"""
 
